@@ -59,7 +59,6 @@ class PIIType(Enum):
     SCREEN_NAME: str = "SCREEN_NAME"
     MARITAL_STATUS: str = "MARITAL_STATUS"
     NUMBER_OF_CHILDREN: str = "NUMBER_OF_CHILDREN"
-    RELIGION: str = "RELIGION"
     COUNTRY_OF_CITIZENSHIP: str = "COUNTRY_OF_CITIZENSHIP"
     VOICE_PRINT: str = "VOICE_PRINT"
     FINGERPRINT: str = "FINGERPRINT"
@@ -70,7 +69,6 @@ class PIIType(Enum):
     DIGITAL_SIGNATURE: str = "DIGITAL_SIGNATURE"
     HEALTH_INSURANCE_ID: str = "HEALTH_INSURANCE_ID"
     SHOPPING_BEHAVIOR: str = "SHOPPING_BEHAVIOR"
-    POLITICAL_AFFILIATION: str = "POLITICAL_AFFILIATION"
     SEXUAL_PREFERENCE: str = "SEXUAL_PREFERENCE"
     SOCIAL_NETWORK_PROFILE: str = "SOCIAL_NETWORK_PROFILE"
     JOB_TITLE: str = "JOB_TITLE"
@@ -84,10 +82,11 @@ class PIIType(Enum):
     US_SOCIAL_SECURITY_NUMBER: str = "US_SOCIAL_SECURITY_NUMBER"
     US_BANK_ACCOUNT_NUMBER: str = "US_BANK_ACCOUNT_NUMBER"
     US_DRIVERS_LICENSE_NUMBER: str = "US_DRIVERS_LICENSE_NUMBER"
-    USUK_PASSPORT_NUMBER: str = "USUK_PASSPORT_NUMBER"
+    US_PASSPORT_NUMBER: str = "US_PASSPORT_NUMBER"
     US_INDIVIDUAL_TAXPAYER_IDENTIFICATION: str = "US_INDIVIDUAL_TAXPAYER_IDENTIFICATION"
     INTERNATIONAL_BANKING_ACCOUNT_NUMBER: str = "INTERNATIONAL_BANKING_ACCOUNT_NUMBER"
     SWIFT_CODE: str = "SWIFTCode"
+    NRP: str = "NRP"  # A person's nationality, religion, or political group
 
 
 class NISTCategory(Enum):
