@@ -20,6 +20,7 @@ class MSFTPresidioPIIType(Enum):
     URL: str = "URL"
     DATE_TIME: str = "DATE_TIME"
     LOCATION: str = "LOCATION"
+    NRP: str = "NRP"
     MEDICAL_LICENSE: str = "MEDICAL_LICENSE"
     US_SOCIAL_SECURITY_NUMBER: str = "US_SSN"
     US_BANK_ACCOUNT_NUMBER: str = "US_BANK_NUMBER"
@@ -27,10 +28,8 @@ class MSFTPresidioPIIType(Enum):
     US_PASSPORT_NUMBER: str = "US_PASSPORT"
     US_INDIVIDUAL_TAXPAYER_IDENTIFICATION: str = "US_ITIN"
     INTERNATIONAL_BANKING_ACCOUNT_NUMBER: str = "IBAN_CODE"
-    UK_NATIONAL_HEALTH_NUMBER: str = "UK_NHS"
+    # UK_NATIONAL_HEALTH_NUMBER: str = "UK_NHS"  # To be added in future versions
     AU_BUSINESS_NUMBER: str = "AU_ABN"
     AU_COMPANY_NUMBER: str = "AU_ACN"
     AU_MEDICAL_ACCOUNT_NUMBER: str = "AU_MEDICARE"
     AU_TAX_FILE_NUMBER: str = "AU_TFN"
-    ES_TAX_IDENTIFICATION_NUMBER: str = "ES_NIF"
-    SG_NATIONAL_REGISTRATION_IDENTITY_CARD_NUMBER: str = "SG_NRIC_FIN"
